﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.IO;
using System.Linq;
using System.Reflection;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace CustomDataLabel
{
    public partial class Form1 : Form
    {
        double _totalSale = double.NaN;
        Random rnd = new Random();
        
        public Form1()
        {
            InitializeComponent();
            var data = GetData();
            _totalSale = data.Sum(x => x.Sales);

            flexChart1.DataSource = data;
            flexChart1.BindingX = "Year";
            flexChart1.Series.Clear();

            flexChart1.Series.Add(new C1.Win.Chart.Series { Name = "Sales", Binding = "Sales", AxisY = new C1.Win.Chart.Axis { Position = C1.Chart.Position.Left, MajorGrid = true, AxisLine = true, Labels = true, Title="Absolute Sales"} });

            flexChart1.AxisY.Position = C1.Chart.Position.Right;
            flexChart1.AxisY.AxisLine = true;
            flexChart1.AxisY.Min = 0;
            flexChart1.AxisY.Max = data.Max(x => x.Sales) / _totalSale;
            flexChart1.AxisY.Format = "p0";
            flexChart1.AxisY.Title = "Percent of Total Sales(%)";
            flexChart1.AxisY.MajorGrid = false;
            flexChart1.ToolTip.Active = false;

            flexChart1.DataLabel.Content = "{Sales}";
            flexChart1.DataLabel.Position = C1.Chart.LabelPosition.Top;
            flexChart1.LabelRendering += FlexChart1_LabelRendering;

            this.WindowState = FormWindowState.Maximized;
        }

        private void FlexChart1_LabelRendering(object sender, C1.Win.Chart.RenderDataLabelEventArgs e)
        {
            e.Text = string.Format("{0:p1}", (e.Item as DataItem).Sales / _totalSale);
        }

        private List<DataItem> GetData()
        {
            var data = new List<DataItem>();
            for(int year = 1995; year <= 2015; year++)
            {
                data.Add(new DataItem { Year = year, Sales = rnd.Next(50, 200) });
            }
            return data;
        }

        private void button1_Click(object sender, EventArgs e)
        {
            var path = Directory.GetParent(Assembly.GetExecutingAssembly().Location.ToString()).Parent.FullName + @"\output.jpg";
            var file = File.OpenWrite(path);
            flexChart1.SaveImage(file, C1.Win.Chart.ImageFormat.Jpg, 500,500);
            file.Close();
            MessageBox.Show("Image saved at : \n"+path);
            Form2 frm = new Form2(path);
            frm.Show();
            
        }
    }
    public class DataItem
    {
        public int Year { get; set; }
        public double Sales { get; set; }
    }
}
